@@ -1,15 +1,20 @@
 from crispy_forms.helper import FormHelper
 from crispy_forms.layout import Layout, Submit, Row, Field
 
-from schema.models import Accessory, Archive, Battery, BulkFilm, Camera, CameraModel, Developer, Enlarger, FilmStock
-from schema.models import Flash, Lens, LensModel
+from schema.models import Accessory, Archive, Battery, BulkFilm, Camera, CameraModel, Developer, Enlarger, EnlargerModel, FilmStock
+from schema.models import Flash, FlashModel, Lens, LensModel
 from schema.models import Mount, MountAdapter, Order, PaperStock, Print
-from schema.models import Repair, Negative, Film, Teleconverter, Toner
+from schema.models import Negative, Film, Teleconverter, TeleconverterModel, Toner
+
+# Disable CSRF token for cleaner filter URLs
+class CustomFormHelper(FormHelper):
+    disable_csrf = True
+
 
 # These helpers are just for the filter forms
 
 
-class AccessoryFormHelper(FormHelper):
+class AccessoryFormHelper(CustomFormHelper):
     model = Accessory
     layout = Layout(
         Row(
@@ -19,7 +24,7 @@ class AccessoryFormHelper(FormHelper):
     )
 
 
-class ArchiveFormHelper(FormHelper):
+class ArchiveFormHelper(CustomFormHelper):
     model = Archive
     layout = Layout(
         Row(
@@ -32,7 +37,7 @@ class ArchiveFormHelper(FormHelper):
     )
 
 
-class BatteryFormHelper(FormHelper):
+class BatteryFormHelper(CustomFormHelper):
     model = Battery
     layout = Layout(
         Row(
@@ -42,7 +47,7 @@ class BatteryFormHelper(FormHelper):
     )
 
 
-class BulkFilmFormHelper(FormHelper):
+class BulkFilmFormHelper(CustomFormHelper):
     model = BulkFilm
     layout = Layout(
         Row(
@@ -52,7 +57,7 @@ class BulkFilmFormHelper(FormHelper):
         )
     )
 
-class CameraFormHelper(FormHelper):
+class CameraFormHelper(CustomFormHelper):
     model = Camera
     layout = Layout(
         Row(
@@ -67,7 +72,7 @@ class CameraFormHelper(FormHelper):
     )
 
 
-class CameraModelFormHelper(FormHelper):
+class CameraModelFormHelper(CustomFormHelper):
     model = CameraModel
     layout = Layout(
         Row(
@@ -82,7 +87,7 @@ class CameraModelFormHelper(FormHelper):
     )
 
 
-class DeveloperFormHelper(FormHelper):
+class DeveloperFormHelper(CustomFormHelper):
     model = Developer
     layout = Layout(
         Row(
@@ -95,8 +100,8 @@ class DeveloperFormHelper(FormHelper):
     )
 
 
-class EnlargerFormHelper(FormHelper):
-    model = Enlarger
+class EnlargerModelFormHelper(CustomFormHelper):
+    model = EnlargerModel
     layout = Layout(
         Row(
             Field('manufacturer', css_class="form-control-sm"),
@@ -108,7 +113,17 @@ class EnlargerFormHelper(FormHelper):
     )
 
 
-class FilmStockFormHelper(FormHelper):
+class EnlargerFormHelper(CustomFormHelper):
+    model = Enlarger
+    layout = Layout(
+        Row(
+            Field('enlargermodel', css_class="form-control-sm"),
+            Submit('filter', 'Filter', css_class="form-control-sm"),
+        )
+    )
+
+
+class FilmStockFormHelper(CustomFormHelper):
     model = FilmStock
     layout = Layout(
         Row(
@@ -122,8 +137,8 @@ class FilmStockFormHelper(FormHelper):
     )
 
 
-class FlashFormHelper(FormHelper):
-    model = Flash
+class FlashModelFormHelper(CustomFormHelper):
+    model = FlashModel
     layout = Layout(
         Row(
             Field('manufacturer', css_class="form-control-sm"),
@@ -135,13 +150,21 @@ class FlashFormHelper(FormHelper):
             Field('tilt_head', css_class="form-control-sm"),
             Field('zoom', css_class="form-control-sm"),
             Field('ttl', css_class="form-control-sm"),
-            Field('flash_protocol', css_class="form-control-sm"),
+            Submit('filter', 'Filter', css_class="form-control-sm"),
+        )
+    )
+
+class FlashFormHelper(CustomFormHelper):
+    model = Flash
+    layout = Layout(
+        Row(
+            Field('flashmodel', css_class="form-control-sm"),
             Submit('filter', 'Filter', css_class="form-control-sm"),
         )
     )
 
 
-class LensFormHelper(FormHelper):
+class LensFormHelper(CustomFormHelper):
     model = Lens
     layout = Layout(
         Row(
@@ -155,7 +178,7 @@ class LensFormHelper(FormHelper):
     )
 
 
-class LensModelFormHelper(FormHelper):
+class LensModelFormHelper(CustomFormHelper):
     model = LensModel
     layout = Layout(
         Row(
@@ -170,7 +193,7 @@ class LensModelFormHelper(FormHelper):
     )
 
 
-class MountFormHelper(FormHelper):
+class MountFormHelper(CustomFormHelper):
     model = Mount
     layout = Layout(
         Row(
@@ -183,7 +206,7 @@ class MountFormHelper(FormHelper):
     )
 
 
-class MountAdapterFormHelper(FormHelper):
+class MountAdapterFormHelper(CustomFormHelper):
     model = MountAdapter
     layout = Layout(
         Row(
@@ -196,7 +219,7 @@ class MountAdapterFormHelper(FormHelper):
     )
 
 
-class OrderFormHelper(FormHelper):
+class OrderFormHelper(CustomFormHelper):
     model = Order
     layout = Layout(
         Row(
@@ -206,7 +229,7 @@ class OrderFormHelper(FormHelper):
     )
 
 
-class PaperStockFormHelper(FormHelper):
+class PaperStockFormHelper(CustomFormHelper):
     model = PaperStock
     layout = Layout(
         Row(
@@ -220,7 +243,7 @@ class PaperStockFormHelper(FormHelper):
     )
 
 
-class PrintFormHelper(FormHelper):
+class PrintFormHelper(CustomFormHelper):
     model = Print
     layout = Layout(
         Row(
@@ -233,32 +256,19 @@ class PrintFormHelper(FormHelper):
     )
 
 
-class RepairFormHelper(FormHelper):
-    model = Repair
-    layout = Layout(
-        Row(
-            Field('camera', css_class="form-control-sm"),
-            Field('lens', css_class="form-control-sm"),
-            Submit('filter', 'Filter', css_class="form-control-sm"),
-        )
-    )
-
-
-class NegativeFormHelper(FormHelper):
+class NegativeFormHelper(CustomFormHelper):
     model = Negative
+    #disable_csrf = True
     layout = Layout(
         Row(
             Field('film', css_class="form-control-sm"),
             Field('lens', css_class="form-control-sm"),
-            Field('filter', css_class="form-control-sm"),
-            Field('metering_mode', css_class="form-control-sm"),
-            Field('exposure_program', css_class="form-control-sm"),
             Submit('filter', 'Filter', css_class="form-control-sm"),
         )
     )
 
 
-class FilmFormHelper(FormHelper):
+class FilmFormHelper(CustomFormHelper):
     model = Film
     layout = Layout(
         Row(
@@ -273,8 +283,18 @@ class FilmFormHelper(FormHelper):
     )
 
 
-class TeleconverterFormHelper(FormHelper):
+class TeleconverterFormHelper(CustomFormHelper):
     model = Teleconverter
+    layout = Layout(
+        Row(
+            Field('teleconvertermodel', css_class="form-control-sm"),
+            Submit('filter', 'Filter', css_class="form-control-sm"),
+        )
+    )
+
+
+class TeleconverterModelFormHelper(CustomFormHelper):
+    model = TeleconverterModel
     layout = Layout(
         Row(
             Field('manufacturer', css_class="form-control-sm"),
@@ -284,7 +304,7 @@ class TeleconverterFormHelper(FormHelper):
     )
 
 
-class TonerFormHelper(FormHelper):
+class TonerFormHelper(CustomFormHelper):
     model = Toner
     layout = Layout(
         Row(
