@@ -6,10 +6,10 @@ from django.urls import reverse
 from schema.funcs import boolicon, colouricon
 
 # Import all models that need admin pages
-from schema.models import Accessory, Archive, Battery, BulkFilm, Camera, CameraModel, Developer, Enlarger, FilmStock, Filter
-from schema.models import Flash, FlashProtocol, Format, Lens, LensModel, Manufacturer
+from schema.models import Accessory, Archive, Battery, BulkFilm, Camera, CameraModel, Developer, Enlarger, EnlargerModel, FilmStock, Filter
+from schema.models import Flash, FlashModel, Format, Lens, LensModel, Manufacturer
 from schema.models import Mount, MountAdapter, NegativeSize, Order, PaperStock, Person, Print
-from schema.models import Process, Repair, Scan, Negative, Film, Teleconverter, Toner
+from schema.models import Process, Scan, Negative, Film, Teleconverter, TeleconverterModel, Toner
 
 
 class AccessoryTable(tables.Table):
@@ -20,27 +20,26 @@ class AccessoryTable(tables.Table):
 
     @classmethod
     def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('accessory-detail', args=[value]), value)
+        return format_html("<a href=\"{}\">#{}</a>", reverse('schema:accessory-detail', args=[value]), value)
 
     @classmethod
     def render_model(cls, value, record):
-        return format_html("<a href=\"{}\">{} {}</a>", reverse('accessory-detail', args=[record.id_owner]), record.manufacturer, value)
+        return format_html("<a href=\"{}\">{} {}</a>", reverse('schema:accessory-detail', args=[record.id_owner]), record.manufacturer, value)
 
 
 class ArchiveTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Archive
-        fields = ('id_owner', 'name', 'type',
-                  'max_width', 'max_height', 'sealed')
+        fields = ('name', 'type', 'max_width', 'max_height', 'sealed')
 
     @classmethod
     def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('archive-detail', args=[value]), value)
+        return format_html("<a href=\"{}\">#{}</a>", reverse('schema:archive-detail', args=[value]), value)
 
     @classmethod
     def render_name(cls, value, record):
-        return format_html("<a href=\"{}\">{}</a>", reverse('archive-detail', args=[record.id_owner]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:archive-detail', args=[record.id_owner]), value)
 
     @classmethod
     def render_sealed(cls, value):
@@ -63,7 +62,7 @@ class BatteryTable(tables.Table):
 
     @classmethod
     def render_name(cls, value, record):
-        return format_html("<a href=\"{}\">{}</a>", reverse('battery-detail', args=[record.slug]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:battery-detail', args=[record.slug]), value)
 
     @classmethod
     def render_voltage(cls, value):
@@ -78,7 +77,7 @@ class BulkFilmTable(tables.Table):
 
     @classmethod
     def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('bulkfilm-detail', args=[value]), value)
+        return format_html("<a href=\"{}\">#{}</a>", reverse('schema:bulkfilm-detail', args=[value]), value)
 
 
 class CameraTable(tables.Table):
@@ -90,11 +89,11 @@ class CameraTable(tables.Table):
 
     @classmethod
     def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('camera-detail', args=[value]), value)
+        return format_html("<a href=\"{}\">#{}</a>", reverse('schema:camera-detail', args=[value]), value)
 
     @classmethod
     def render_cameramodel(cls, value, record):
-        return format_html("<a href=\"{}\">{}</a>", reverse('cameramodel-detail', args=[record.cameramodel.slug]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:cameramodel-detail', args=[record.cameramodel.slug]), value)
 
     @classmethod
     def render_serial(cls, value):
@@ -115,11 +114,11 @@ class CameraModelTable(tables.Table):
     @classmethod
     def render_model(cls, value, record):
         if record.disambiguation:
-            mystr = format_html("<a href=\"{}\">{} {} [{}]</a>", reverse('cameramodel-detail', args=[
+            mystr = format_html("<a href=\"{}\">{} {} [{}]</a>", reverse('schema:cameramodel-detail', args=[
                 record.slug]), record.manufacturer, value, record.disambiguation)
         else:
             mystr = format_html("<a href=\"{}\">{} {}</a>", reverse(
-                'cameramodel-detail', args=[record.slug]), record.manufacturer, value)
+                'schema:cameramodel-detail', args=[record.slug]), record.manufacturer, value)
         if cls.request.user.is_authenticated:
             qty = Camera.objects.filter(
                 owner=cls.request.user, cameramodel=record).count()
@@ -135,20 +134,21 @@ class CameraModelTable(tables.Table):
     @classmethod
     def render_image(cls, value):
         if value:
-            icon = format_html('<img src="/static/svg/camera.svg" width="20" height="20" alt="This camera model has a photo" title="This camera model has a photo">')
+            icon = format_html(
+                '<img src="/static/svg/camera.svg" width="20" height="20" alt="This camera model has a photo" title="This camera model has a photo">')
         return icon
 
     @classmethod
     def render_mount(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('mount-detail', args=[value.slug]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:mount-detail', args=[value.slug]), value)
 
     @classmethod
     def render_format(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('format-detail', args=[value.id]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:format-detail', args=[value.id]), value)
 
     @classmethod
     def render_negative_size(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('negativesize-detail', args=[value.id]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:negativesize-detail', args=[value.id]), value)
 
 
 class DeveloperTable(tables.Table):
@@ -159,7 +159,7 @@ class DeveloperTable(tables.Table):
 
     @classmethod
     def render_name(cls, value, record):
-        return format_html("<a href=\"{}\">{} {}</a>", reverse('developer-detail', args=[record.slug]), record.manufacturer, value)
+        return format_html("<a href=\"{}\">{} {}</a>", reverse('schema:developer-detail', args=[record.slug]), record.manufacturer, value)
 
     @classmethod
     def render_for_paper(cls, value):
@@ -170,19 +170,30 @@ class DeveloperTable(tables.Table):
         return format_html(boolicon(value))
 
 
+class EnlargerModelTable(tables.Table):
+    class Meta:
+        attrs = {"class": "table table-hover"}
+        model = EnlargerModel
+        fields = ('model', 'negative_size', 'type')
+
+    @classmethod
+    def render_model(cls, value, record):
+        return format_html("<a href=\"{}\">{} {}</a>", reverse('schema:enlargermodel-detail', args=[record.slug]), record.manufacturer, value)
+
+
 class EnlargerTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Enlarger
-        fields = ('id_owner', 'model', 'negative_size', 'type')
+        fields = ('id_owner', 'enlargermodel')
 
     @classmethod
     def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('enlarger-detail', args=[value]), value)
+        return format_html("<a href=\"{}\">#{}</a>", reverse('schema:enlarger-detail', args=[value]), value)
 
     @classmethod
-    def render_model(cls, value, record):
-        return format_html("<a href=\"{}\">{} {}</a>", reverse('enlarger-detail', args=[record.id_owner]), record.manufacturer, value)
+    def render_enlargermodel(cls, value, record):
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:enlargermodel-detail', args=[record.enlargermodel.slug]), value)
 
 
 class FilmStockTable(tables.Table):
@@ -193,7 +204,7 @@ class FilmStockTable(tables.Table):
 
     @classmethod
     def render_name(cls, value, record):
-        return format_html("<a href=\"{}\">{} {}</a>", reverse('filmstock-detail', args=[record.slug]), record.manufacturer, value)
+        return format_html("<a href=\"{}\">{} {}</a>", reverse('schema:filmstock-detail', args=[record.slug]), record.manufacturer, value)
 
     @classmethod
     def render_colour(cls, value):
@@ -212,43 +223,37 @@ class FilterTable(tables.Table):
 
     @classmethod
     def render_type(cls, value, record):
-        return format_html("<a href=\"{}\">{}</a>", reverse('filter-detail', args=[record.id]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:filter-detail', args=[record.id]), value)
 
 
-class FlashTable(tables.Table):
+class FlashModelTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
-        model = Flash
-        fields = ('id_owner', 'model', 'guide_number', 'ttl', 'flash_protocol')
-
-    @classmethod
-    def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('flash-detail', args=[value]), value)
+        model = FlashModel
+        fields = ('model', 'guide_number', 'ttl')
 
     @classmethod
     def render_model(cls, value, record):
-        return format_html("<a href=\"{}\">{} {}</a>", reverse('flash-detail', args=[record.id_owner]), record.manufacturer, value)
+        return format_html("<a href=\"{}\">{} {}</a>", reverse('schema:flashmodel-detail', args=[record.slug]), record.manufacturer, value)
 
     @classmethod
     def render_ttl(cls, value):
         return format_html(boolicon(value))
 
 
-class FlashProtocolTable(tables.Table):
+class FlashTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
-        model = FlashProtocol
-        fields = ('name',)
+        model = Flash
+        fields = ('id_owner', 'flashmodel')
 
     @classmethod
-    def render_name(cls, value, record):
-        if record.manufacturer is not None:
-            mystr = format_html("<a href=\"{}\">{} {}</a>", reverse(
-                'flashprotocol-detail', args=[record.id]), record.manufacturer, value)
-        else:
-            mystr = format_html(
-                "<a href=\"{}\">{}</a>", reverse('flashprotocol-detail', args=[record.id]), value)
-        return mystr
+    def render_id_owner(cls, value):
+        return format_html("<a href=\"{}\">#{}</a>", reverse('schema:flash-detail', args=[value]), value)
+
+    @classmethod
+    def render_flashmodel(cls, value, record):
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:flashmodel-detail', args=[record.flashmodel.slug]), value)
 
 
 class FormatTable(tables.Table):
@@ -259,7 +264,7 @@ class FormatTable(tables.Table):
 
     @classmethod
     def render_format(cls, value, record):
-        return format_html("<a href=\"{}\">{}</a>", reverse('format-detail', args=[record.id]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:format-detail', args=[record.id]), value)
 
 
 class LensTable(tables.Table):
@@ -271,15 +276,15 @@ class LensTable(tables.Table):
 
     @classmethod
     def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('lens-detail', args=[value]), value)
+        return format_html("<a href=\"{}\">#{}</a>", reverse('schema:lens-detail', args=[value]), value)
 
     @classmethod
     def render_lensmodel(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('lensmodel-detail', args=[value.slug]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:lensmodel-detail', args=[value.slug]), value)
 
     @classmethod
     def render_lensmodel__mount(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('mount-detail', args=[value.slug]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:mount-detail', args=[value.slug]), value)
 
     @classmethod
     def render_serial(cls, value):
@@ -300,11 +305,11 @@ class LensModelTable(tables.Table):
     @classmethod
     def render_model(cls, value, record):
         if record.disambiguation:
-            mystr = format_html("<a href=\"{}\">{} {} [{}]</a>", reverse('lensmodel-detail', args=[
+            mystr = format_html("<a href=\"{}\">{} {} [{}]</a>", reverse('schema:lensmodel-detail', args=[
                 record.slug]), record.manufacturer, value, record.disambiguation)
         else:
             mystr = format_html("<a href=\"{}\">{} {}</a>", reverse(
-                'lensmodel-detail', args=[record.slug]), record.manufacturer, value)
+                'schema:lensmodel-detail', args=[record.slug]), record.manufacturer, value)
         if cls.request.user.is_authenticated:
             qty = Lens.objects.filter(
                 owner=cls.request.user, lensmodel=record).count()
@@ -320,12 +325,13 @@ class LensModelTable(tables.Table):
     @classmethod
     def render_image(cls, value):
         if value:
-            icon = format_html('<img src="/static/svg/camera.svg" width="20" height="20" alt="This lens model has a photo" title="This lens model has a photo">')
+            icon = format_html(
+                '<img src="/static/svg/camera.svg" width="20" height="20" alt="This lens model has a photo" title="This lens model has a photo">')
         return icon
 
     @classmethod
     def render_mount(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('mount-detail', args=[value.slug]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:mount-detail', args=[value.slug]), value)
 
     @classmethod
     def render_max_aperture(cls, value):
@@ -359,7 +365,7 @@ class ManufacturerTable(tables.Table):
 
     @classmethod
     def render_name(cls, value, record):
-        return format_html("<a href=\"{}\">{}</a>", reverse('manufacturer-detail', args=[record.slug]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:manufacturer-detail', args=[record.slug]), value)
 
     @classmethod
     def render_country(cls, record):
@@ -374,7 +380,7 @@ class MountTable(tables.Table):
 
     @classmethod
     def render_mount(cls, value, record):
-        return format_html("<a href=\"{}\">{}</a>", reverse('mount-detail', args=[record.slug]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:mount-detail', args=[record.slug]), value)
 
     @classmethod
     def render_shutter_in_lens(cls, value):
@@ -390,15 +396,15 @@ class MountAdapterTable(tables.Table):
 
     @classmethod
     def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('mountadapter-detail', args=[value]), value)
+        return format_html("<a href=\"{}\">#{}</a>", reverse('schema:mountadapter-detail', args=[value]), value)
 
     @classmethod
     def render_camera_mount(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('mount-detail', args=[value.slug]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:mount-detail', args=[value.slug]), value)
 
     @classmethod
     def render_lens_mount(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('mount-detail', args=[value.slug]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:mount-detail', args=[value.slug]), value)
 
 
 class NegativeSizeTable(tables.Table):
@@ -410,7 +416,7 @@ class NegativeSizeTable(tables.Table):
 
     @classmethod
     def render_name(cls, value, record):
-        return format_html("<a href=\"{}\">{}</a>", reverse('negativesize-detail', args=[record.id]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:negativesize-detail', args=[record.id]), value)
 
     @classmethod
     def render_width(cls, value):
@@ -442,7 +448,7 @@ class OrderTable(tables.Table):
 
     @classmethod
     def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('order-detail', args=[value]), value)
+        return format_html("<a href=\"{}\">#{}</a>", reverse('schema:order-detail', args=[value]), value)
 
 
 class PaperStockTable(tables.Table):
@@ -453,7 +459,7 @@ class PaperStockTable(tables.Table):
 
     @classmethod
     def render_name(cls, value, record):
-        return format_html("<a href=\"{}\">{} {}</a>", reverse('paperstock-detail', args=[record.id]), record.manufacturer, value)
+        return format_html("<a href=\"{}\">{} {}</a>", reverse('schema:paperstock-detail', args=[record.id]), record.manufacturer, value)
 
     @classmethod
     def render_resin_coated(cls, value):
@@ -472,11 +478,11 @@ class PersonTable(tables.Table):
 
     @classmethod
     def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('person-detail', args=[value]), value)
+        return format_html("<a href=\"{}\">#{}</a>", reverse('schema:person-detail', args=[value]), value)
 
     @classmethod
     def render_name(cls, value, record):
-        return format_html("<a href=\"{}\">{}</a>", reverse('person-detail', args=[record.id_owner]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:person-detail', args=[record.id_owner]), value)
 
 
 class PrintTable(tables.Table):
@@ -488,11 +494,11 @@ class PrintTable(tables.Table):
 
     @classmethod
     def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('print-detail', args=[value]), value)
+        return format_html("<a href=\"{}\">#{}</a>", reverse('schema:print-detail', args=[value]), value)
 
     @classmethod
     def render_negative(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('negative-detail', args=[value.id_owner]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:negative-detail', args=[value.id_owner]), value)
 
 
 class ProcessTable(tables.Table):
@@ -503,7 +509,7 @@ class ProcessTable(tables.Table):
 
     @classmethod
     def render_name(cls, value, record):
-        return format_html("<a href=\"{}\">{}</a>", reverse('process-detail', args=[record.id]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:process-detail', args=[record.id]), value)
 
     @classmethod
     def render_colour(cls, value):
@@ -514,35 +520,27 @@ class ProcessTable(tables.Table):
         return format_html(boolicon(value))
 
 
-class RepairTable(tables.Table):
-    class Meta:
-        attrs = {"class": "table table-hover"}
-        model = Repair
-        fields = ('id_owner', 'camera', 'lens', 'date', 'summary')
-
-    @classmethod
-    def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('repair-detail', args=[value]), value)
-
-    @classmethod
-    def render_camera(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('camera-detail', args=[value.id_owner]), value)
-
-    @classmethod
-    def render_lens(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('lens-detail', args=[value.id_owner]), value)
-
-
 class ScanTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Scan
-        fields = ('id_owner', 'negative', 'print', 'filename',
-                  'date', 'colour', 'width', 'height')
+        fields = ('uuid', 'negative', 'print', 'filename', 'date')
 
     @classmethod
-    def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('scan-detail', args=[value]), value)
+    def render_uuid(cls, value):
+        return format_html("<code><a href=\"{}\">{}</a></code>", reverse('schema:scan-detail', args=[value]), value)
+
+    @classmethod
+    def render_negative(cls, value):
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:negative-detail', args=[value.id_owner]), value)
+
+    @classmethod
+    def render_print(cls, value):
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:print-detail', args=[value.id_owner]), value)
+
+    @classmethod
+    def render_filename(cls, value):
+        return format_html("<code>{}</code>", value)
 
 
 class NegativeTable(tables.Table):
@@ -553,50 +551,62 @@ class NegativeTable(tables.Table):
 
     @classmethod
     def render_id_owner(cls, value, record):
-        return format_html("<a href=\"{}\">{}</a>", reverse('negative-detail', args=[value]), record)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:negative-detail', args=[value]), record)
 
 
 class FilmTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Film
-        fields = ('id_owner', 'filmstock', 'format', 'status', 'date_processed', 'camera')
+        fields = ('id_owner', 'filmstock', 'format',
+                  'status', 'date_processed', 'camera')
 
     @classmethod
     def render_id_owner(cls, value, record):
-        return format_html("<a href=\"{}\">{}</a>", reverse('film-detail', args=[value]), record)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:film-detail', args=[value]), record)
 
     @classmethod
     def render_filmstock(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('filmstock-detail', args=[value.slug]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:filmstock-detail', args=[value.slug]), value)
 
     @classmethod
     def render_format(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('format-detail', args=[value.id]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:format-detail', args=[value.id]), value)
 
     @classmethod
     def render_camera(cls, value):
-        return format_html("<a href=\"{}\">{}</a>", reverse('camera-detail', args=[value.id_owner]), value)
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:camera-detail', args=[value.id_owner]), value)
 
 
 class TeleconverterTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Teleconverter
-        fields = ('id_owner', 'model', 'mount', 'factor')
+        fields = ('id_owner', 'teleconvertermodel',)
 
     @classmethod
     def render_id_owner(cls, value):
-        return format_html("<a href=\"{}\">#{}</a>", reverse('teleconverter-detail', args=[value]), value)
+        return format_html("<a href=\"{}\">#{}</a>", reverse('schema:teleconverter-detail', args=[value]), value)
+
+    @classmethod
+    def render_model(cls, value, record):
+        return format_html("<a href=\"{}\">{}</a>", reverse('schema:teleconvertermodel-detail', args=[record.teleconvertermodel.slug]), value)
+
+
+class TeleconverterModelTable(tables.Table):
+    class Meta:
+        attrs = {"class": "table table-hover"}
+        model = TeleconverterModel
+        fields = ('model', 'mount', 'factor')
 
     @classmethod
     def render_model(cls, value, record):
         if record.manufacturer is not None:
             mystr = format_html("<a href=\"{}\">{} {}</a>", reverse(
-                'teleconverter-detail', args=[record.id_owner]), record.manufacturer, value)
+                'schema:teleconvertermodel-detail', args=[record.slug]), record.manufacturer, value)
         else:
             mystr = format_html(
-                "<a href=\"{}\">{}</a>", reverse('teleconverter-detail', args=[record.id]), value)
+                "<a href=\"{}\">{}</a>", reverse('schema:teleconvertermodel-detail', args=[record.slug]), value)
         return mystr
 
     @classmethod
@@ -612,4 +622,4 @@ class TonerTable(tables.Table):
 
     @classmethod
     def render_name(cls, value, record):
-        return format_html("<a href=\"{}\">{} {}</a>", reverse('toner-detail', args=[record.slug]), record.manufacturer, value)
+        return format_html("<a href=\"{}\">{} {}</a>", reverse('schema:toner-detail', args=[record.slug]), record.manufacturer, value)
