@@ -5,6 +5,7 @@ from django.conf.urls.static import static
 
 from schema import views
 
+app_name = 'schema'
 urlpatterns = [
 
     # Static pages
@@ -15,7 +16,8 @@ urlpatterns = [
 
     path('tag/', views.TagList.as_view(), name='tag-list'),
     path('tag/<slug:slug>', views.TagDetail.as_view(), name='tag-detail'),
-    path('tag-autocomplete/', views.TagAutocomplete.as_view(), name='tag-autocomplete'),
+    path('tag-autocomplete/', views.TagAutocomplete.as_view(),
+         name='tag-autocomplete'),
 
     path('accessory/', views.AccessoryList.as_view(), name='accessory-list'),
     path('accessory/<int:id_owner>', views.AccessoryDetail.as_view(),
@@ -50,7 +52,8 @@ urlpatterns = [
     path('camera/create/', views.CameraCreate.as_view(), name='camera-create'),
     path('camera/<int:id_owner>/update',
          views.CameraUpdate.as_view(), name='camera-update'),
-    path('camera/<int:id_owner>/sell', views.CameraSell.as_view(), name='camera-sell'),
+    path('camera/<int:id_owner>/sell',
+         views.CameraSell.as_view(), name='camera-sell'),
 
     path('cameramodel/', views.CameraModelList.as_view(), name='cameramodel-list'),
     path('cameramodel/<slug:slug>', views.CameraModelDetail.as_view(),
@@ -68,6 +71,15 @@ urlpatterns = [
     path('developer/<slug:slug>/update',
          views.DeveloperUpdate.as_view(), name='developer-update'),
 
+    path('enlargermodel/', views.EnlargerModelList.as_view(),
+         name='enlargermodel-list'),
+    path('enlargermodel/<slug:slug>', views.EnlargerModelDetail.as_view(),
+         name='enlargermodel-detail'),
+    path('enlargermodel/create/', views.EnlargerModelCreate.as_view(),
+         name='enlargermodel-create'),
+    path('enlargermodel/<slug:slug>/update',
+         views.EnlargerModelUpdate.as_view(), name='enlargermodel-update'),
+
     path('enlarger/', views.EnlargerList.as_view(), name='enlarger-list'),
     path('enlarger/<int:id_owner>',
          views.EnlargerDetail.as_view(), name='enlarger-detail'),
@@ -95,14 +107,13 @@ urlpatterns = [
     path('flash/<int:id_owner>/update',
          views.FlashUpdate.as_view(), name='flash-update'),
 
-    path('flashprotocol/', views.FlashProtocolList.as_view(),
-         name='flashprotocol-list'),
-    path('flashprotocol/<int:pk>', views.FlashProtocolDetail.as_view(),
-         name='flashprotocol-detail'),
-    path('flashprotocol/create/', views.FlashProtocolCreate.as_view(),
-         name='flashprotocol-create'),
-    path('flashprotocol/<int:pk>/update',
-         views.FlashProtocolUpdate.as_view(), name='flashprotocol-update'),
+    path('flashmodel/', views.FlashModelList.as_view(), name='flashmodel-list'),
+    path('flashmodel/<slug:slug>', views.FlashModelDetail.as_view(),
+         name='flashmodel-detail'),
+    path('flashmodel/create/', views.FlashModelCreate.as_view(),
+         name='flashmodel-create'),
+    path('flashmodel/<slug:slug>/update',
+         views.FlashModelUpdate.as_view(), name='flashmodel-update'),
 
     path('format/', views.FormatList.as_view(), name='format-list'),
     path('format/<int:pk>', views.FormatDetail.as_view(), name='format-detail'),
@@ -190,16 +201,10 @@ urlpatterns = [
     path('process/<int:pk>/update',
          views.ProcessUpdate.as_view(), name='process-update'),
 
-    path('repair/', views.RepairList.as_view(), name='repair-list'),
-    path('repair/<int:id_owner>', views.RepairDetail.as_view(), name='repair-detail'),
-    path('repair/create/', views.RepairCreate.as_view(), name='repair-create'),
-    path('repair/<int:id_owner>/update',
-         views.RepairUpdate.as_view(), name='repair-update'),
-
     path('scan/', views.ScanList.as_view(), name='scan-list'),
-    path('scan/<int:id_owner>', views.ScanDetail.as_view(), name='scan-detail'),
+    path('scan/<uuid:uuid>', views.ScanDetail.as_view(), name='scan-detail'),
     path('scan/create/', views.ScanCreate.as_view(), name='scan-create'),
-    path('scan/<int:id_owner>/update',
+    path('scan/<uuid:uuid>/update',
          views.ScanUpdate.as_view(), name='scan-update'),
 
     path('negative/', views.NegativeList.as_view(), name='negative-list'),
@@ -215,18 +220,29 @@ urlpatterns = [
     path('film/<int:id_owner>/update',
          views.FilmUpdate.as_view(), name='film-update'),
     path('film/<int:id_owner>/load', views.FilmLoad.as_view(), name='film-load'),
-    path('film/<int:id_owner>/develop', views.FilmDevelop.as_view(), name='film-develop'),
-    path('film/<int:id_owner>/archive', views.FilmArchive.as_view(), name='film-archive'),
+    path('film/<int:id_owner>/develop',
+         views.FilmDevelop.as_view(), name='film-develop'),
+    path('film/<int:id_owner>/archive',
+         views.FilmArchive.as_view(), name='film-archive'),
 
     path('teleconverter/', views.TeleconverterList.as_view(),
          name='teleconverter-list'),
-    path('teleconverter/<int:id_owner>', views.TeleconverterDetail.as_view(),
-         name='teleconverter-detail'),
+    path('teleconverter/<int:id_owner>',
+         views.TeleconverterDetail.as_view(), name='teleconverter-detail'),
     path('teleconverter/create/', views.TeleconverterCreate.as_view(),
          name='teleconverter-create'),
     path('teleconverter/<int:id_owner>/update',
          views.TeleconverterUpdate.as_view(), name='teleconverter-update'),
 
+    path('teleconvertermodel/', views.TeleconverterModelList.as_view(),
+         name='teleconvertermodel-list'),
+    path('teleconvertermodel/<slug:slug>',
+         views.TeleconverterModelDetail.as_view(), name='teleconvertermodel-detail'),
+    path('teleconvertermodel/create/', views.TeleconverterModelCreate.as_view(),
+         name='teleconvertermodel-create'),
+    path('teleconvertermodel/<slug:slug>/update',
+         views.TeleconverterModelUpdate.as_view(), name='teleconvertermodel-update'),
+
     path('toner/', views.TonerList.as_view(), name='toner-list'),
     path('toner/<slug:slug>', views.TonerDetail.as_view(), name='toner-detail'),
     path('toner/create/', views.TonerCreate.as_view(), name='toner-create'),
