@@ -16,30 +16,30 @@ from watson.views import SearchMixin
 from taggit.models import Tag
 from dal import autocomplete
 
-from schema.models import Accessory, Archive, Battery, BulkFilm, Camera, CameraModel, Developer, Enlarger, FilmStock, Filter
-from schema.models import Flash, FlashProtocol, Format, Lens, LensModel, Manufacturer
+from schema.models import Accessory, Archive, Battery, BulkFilm, Camera, CameraModel, Developer, Enlarger, EnlargerModel, FilmStock, Filter
+from schema.models import Flash, FlashModel, Format, Lens, LensModel, Manufacturer
 from schema.models import Mount, MountAdapter, NegativeSize, Order, PaperStock, Person, Print
-from schema.models import Process, Repair, Scan, Negative, Film, Teleconverter, Toner
+from schema.models import Process, Scan, Negative, Film, Teleconverter, TeleconverterModel, Toner
 
-from schema.tables import AccessoryTable, ArchiveTable, BatteryTable, BulkFilmTable, CameraTable, CameraModelTable, DeveloperTable, EnlargerTable, FilmStockTable, FilterTable
-from schema.tables import FlashTable, FlashProtocolTable, FormatTable, LensTable, LensModelTable, ManufacturerTable
+from schema.tables import AccessoryTable, ArchiveTable, BatteryTable, BulkFilmTable, CameraTable, CameraModelTable, DeveloperTable, EnlargerTable, EnlargerModelTable, FilmStockTable, FilterTable
+from schema.tables import FlashTable, FlashModelTable, FormatTable, LensTable, LensModelTable, ManufacturerTable
 from schema.tables import MountTable, MountAdapterTable, NegativeSizeTable, OrderTable, PaperStockTable, PersonTable, PrintTable
-from schema.tables import ProcessTable, RepairTable, ScanTable, NegativeTable, FilmTable, TeleconverterTable, TonerTable
+from schema.tables import ProcessTable, ScanTable, NegativeTable, FilmTable, TeleconverterTable, TeleconverterModelTable, TonerTable
 
-from schema.forms import AccessoryForm, ArchiveForm, BatteryForm, BulkFilmForm, CameraForm, CameraSellForm, CameraModelForm, DeveloperForm, EnlargerForm, FilmStockForm, FilterForm
-from schema.forms import FlashForm, FlashProtocolForm, FormatForm, LensForm, LensSellForm, LensModelForm, ManufacturerForm
+from schema.forms import AccessoryForm, ArchiveForm, BatteryForm, BulkFilmForm, CameraForm, CameraSellForm, CameraModelForm, DeveloperForm, EnlargerForm, EnlargerModelForm, FilmStockForm, FilterForm
+from schema.forms import FlashForm, FlashModelForm, FormatForm, LensForm, LensSellForm, LensModelForm, ManufacturerForm
 from schema.forms import MountForm, MountAdapterForm, NegativeSizeForm, OrderForm, PaperStockForm, PersonForm, PrintForm
-from schema.forms import ProcessForm, RepairForm, ScanForm, NegativeForm, FilmForm, FilmAddForm, FilmLoadForm, FilmDevelopForm, FilmArchiveForm, TeleconverterForm, TonerForm
+from schema.forms import ProcessForm, ScanForm, NegativeForm, FilmForm, FilmAddForm, FilmLoadForm, FilmDevelopForm, FilmArchiveForm, TeleconverterForm, TeleconverterModelForm, TonerForm
 
 from schema.filters import AccessoryFilter, BatteryFilter, BulkFilmFilter, CameraFilter, CameraModelFilter, DeveloperFilter
-from schema.filters import EnlargerFilter, FilmFilter, FilmStockFilter, FlashFilter, LensFilter, LensModelFilter
+from schema.filters import EnlargerFilter, EnlargerModelFilter, FilmFilter, FilmStockFilter, FlashFilter, FlashModelFilter, LensFilter, LensModelFilter
 from schema.filters import MountAdapterFilter, MountFilter, NegativeFilter, OrderFilter, PaperStockFilter, PrintFilter
-from schema.filters import RepairFilter, TeleconverterFilter, TonerFilter
+from schema.filters import TeleconverterFilter, TeleconverterModelFilter, TonerFilter
 
 from schema.formhelpers import AccessoryFormHelper, BatteryFormHelper, BulkFilmFormHelper, CameraFormHelper, CameraModelFormHelper
-from schema.formhelpers import DeveloperFormHelper, EnlargerFormHelper, FilmFormHelper, FilmStockFormHelper, FlashFormHelper
+from schema.formhelpers import DeveloperFormHelper, EnlargerFormHelper, EnlargerModelFormHelper, FilmFormHelper, FilmStockFormHelper, FlashFormHelper, FlashModelFormHelper
 from schema.formhelpers import LensFormHelper, LensModelFormHelper, MountAdapterFormHelper, MountFormHelper, NegativeFormHelper
-from schema.formhelpers import OrderFormHelper, PaperStockFormHelper, PrintFormHelper, RepairFormHelper, TeleconverterFormHelper, TonerFormHelper
+from schema.formhelpers import OrderFormHelper, PaperStockFormHelper, PrintFormHelper, TeleconverterFormHelper, TeleconverterModelFormHelper, TonerFormHelper
 
 from .funcs import to_dict
 
@@ -352,6 +352,27 @@ class DeveloperUpdate(LoginRequiredMixin, UpdateView):
     template_name = 'update.html'
 
 
+class EnlargerModelList(LoginRequiredMixin, PagedFilteredTableView):
+    model = EnlargerModel
+    table_class = EnlargerModelTable
+    filterset_class = EnlargerModelFilter
+    formhelper_class = EnlargerModelFormHelper
+
+
+class EnlargerModelDetail(LoginRequiredMixin, generic.DetailView):
+    model = EnlargerModel
+
+class EnlargerModelCreate(LoginRequiredMixin, CreateView):
+    model = EnlargerModel
+    form_class = EnlargerModelForm
+    template_name = 'create.html'
+
+
+class EnlargerModelUpdate(LoginRequiredMixin, UpdateView):
+    model = EnlargerModel
+    form_class = EnlargerModelForm
+    template_name = 'update.html'
+
 class EnlargerList(LoginRequiredMixin, PagedFilteredTableView):
     model = Enlarger
     table_class = EnlargerTable
@@ -443,6 +464,29 @@ class FilterUpdate(LoginRequiredMixin, UpdateView):
     template_name = 'update.html'
 
 
+class FlashModelList(LoginRequiredMixin, PagedFilteredTableView):
+    model = FlashModel
+    table_class = FlashModelTable
+    filterset_class = FlashModelFilter
+    formhelper_class = FlashModelFormHelper
+
+
+class FlashModelDetail(LoginRequiredMixin, generic.DetailView):
+    model = FlashModel
+
+
+class FlashModelCreate(LoginRequiredMixin, CreateView):
+    model = FlashModel
+    form_class = FlashModelForm
+    template_name = 'create.html'
+
+
+class FlashModelUpdate(LoginRequiredMixin, UpdateView):
+    model = FlashModel
+    form_class = FlashModelForm
+    template_name = 'update.html'
+
+
 class FlashList(LoginRequiredMixin, PagedFilteredTableView):
     model = Flash
     table_class = FlashTable
@@ -474,33 +518,6 @@ class FlashUpdate(LoginRequiredMixin, UpdateView):
         return get_object_or_404(Flash, owner=self.request.user, id_owner=self.kwargs['id_owner'])
 
 
-class FlashProtocolList(SingleTableListView):
-    model = FlashProtocol
-    table_class = FlashProtocolTable
-
-    def get_context_data(self, **kwargs):
-        context = super().get_context_data(**kwargs)
-        if self.get_object().history.all():
-            context['history'] = self.get_object().history.all()
-        return context
-
-
-class FlashProtocolDetail(generic.DetailView):
-    model = FlashProtocol
-
-
-class FlashProtocolCreate(LoginRequiredMixin, CreateView):
-    model = FlashProtocol
-    form_class = FlashProtocolForm
-    template_name = 'create.html'
-
-
-class FlashProtocolUpdate(LoginRequiredMixin, UpdateView):
-    model = FlashProtocol
-    form_class = FlashProtocolForm
-    template_name = 'update.html'
-
-
 class FormatList(SingleTableListView):
     model = Format
     table_class = FormatTable
@@ -935,37 +952,6 @@ class ProcessUpdate(LoginRequiredMixin, UpdateView):
     template_name = 'update.html'
 
 
-class RepairList(LoginRequiredMixin, PagedFilteredTableView):
-    model = Repair
-    table_class = RepairTable
-    filterset_class = RepairFilter
-    formhelper_class = RepairFormHelper
-
-
-class RepairDetail(LoginRequiredMixin, generic.DetailView):
-    model = Repair
-
-    # Restrict to objects we own
-    def get_object(self):
-        return get_object_or_404(Repair, owner=self.request.user, id_owner=self.kwargs['id_owner'])
-
-
-class RepairCreate(LoginRequiredMixin, CreateView):
-    model = Repair
-    form_class = RepairForm
-    template_name = 'create.html'
-
-
-class RepairUpdate(LoginRequiredMixin, UpdateView):
-    model = Repair
-    form_class = RepairForm
-    template_name = 'update.html'
-
-    # Restrict to objects we own
-    def get_object(self):
-        return get_object_or_404(Repair, owner=self.request.user, id_owner=self.kwargs['id_owner'])
-
-
 class ScanList(LoginRequiredMixin, SingleTableListView):
     model = Scan
     table_class = ScanTable
@@ -983,7 +969,7 @@ class ScanDetail(LoginRequiredMixin, generic.DetailView):
 
     # Restrict to objects we own
     def get_object(self):
-        return get_object_or_404(Scan, owner=self.request.user, id_owner=self.kwargs['id_owner'])
+        return get_object_or_404(Scan, owner=self.request.user, uuid=self.kwargs['uuid'])
 
 
 class ScanCreate(LoginRequiredMixin, CreateView):
@@ -999,7 +985,7 @@ class ScanUpdate(LoginRequiredMixin, UpdateView):
 
     # Restrict to objects we own
     def get_object(self):
-        return get_object_or_404(Scan, owner=self.request.user, id_owner=self.kwargs['id_owner'])
+        return get_object_or_404(Scan, owner=self.request.user, uuid=self.kwargs['uuid'])
 
 
 class NegativeList(LoginRequiredMixin, PagedFilteredTableView):
@@ -1124,6 +1110,28 @@ class TeleconverterUpdate(LoginRequiredMixin, UpdateView):
     def get_object(self):
         return get_object_or_404(Teleconverter, owner=self.request.user, id_owner=self.kwargs['id_owner'])
 
+class TeleconverterModelList(LoginRequiredMixin, PagedFilteredTableView):
+    model = TeleconverterModel
+    table_class = TeleconverterModelTable
+    filterset_class = TeleconverterModelFilter
+    formhelper_class = TeleconverterModelFormHelper
+
+
+class TeleconverterModelDetail(LoginRequiredMixin, generic.DetailView):
+    model = TeleconverterModel
+
+
+class TeleconverterModelCreate(LoginRequiredMixin, CreateView):
+    model = TeleconverterModel
+    form_class = TeleconverterModelForm
+    template_name = 'create.html'
+
+
+class TeleconverterModelUpdate(LoginRequiredMixin, UpdateView):
+    model = TeleconverterModel
+    form_class = TeleconverterModelForm
+    template_name = 'update.html'
+
 
 class TonerList(PagedFilteredTableView):
     model = Toner
@@ -1172,26 +1180,26 @@ class StatsView(TemplateView):
         context = super().get_context_data(**kwargs)
         stats = [
             {
-                'image': "svg/cameramodel.svg",
-                'url': reverse('cameramodel-list'),
+                'image': "svg/camera.svg",
+                'url': reverse('schema:cameramodel-list'),
                 'item': "camera models in CameraHub",
                 'value': CameraModel.objects.count,
             },
             {
-                'image': "svg/lensmodel.svg",
-                'url': reverse('lensmodel-list'),
+                'image': "svg/lens.svg",
+                'url': reverse('schema:lensmodel-list'),
                 'item': "lens models in CameraHub",
                 'value': LensModel.objects.count,
             },
             {
                 'image': "svg/filmstock.svg",
-                'url': reverse('filmstock-list'),
+                'url': reverse('schema:filmstock-list'),
                 'item': "film stocks in CameraHub",
                 'value': FilmStock.objects.count
             },
             {
                 'image': "svg/manufacturer.svg",
-                'url': reverse('manufacturer-list'),
+                'url': reverse('schema:manufacturer-list'),
                 'item': "manufacturers in CameraHub",
                 'value': Manufacturer.objects.count
             },
@@ -1257,7 +1265,7 @@ class StatsView(TemplateView):
         stats.append(
             {
                 'image': "svg/weight.svg",
-                'url': reverse('cameramodel-list'),
+                'url': reverse('schema:cameramodel-list'),
                 'item': "total weight of all cameras in CameraHub",
                 'value': str(round((CameraModel.objects.all().aggregate(totalweight=Sum('weight'))['totalweight'] or 0.00)/1000)) + 'kg',
             }
@@ -1266,7 +1274,7 @@ class StatsView(TemplateView):
         stats.append(
             {
                 'image': "svg/ruler.svg",
-                'url': reverse('lensmodel-list'),
+                'url': reverse('schema:lensmodel-list'),
                 'item': "total length of all lenses in CameraHub, laid end to end",
                 'value': str(round((LensModel.objects.all().aggregate(totallength=Sum('length'))['totallength'] or 0.00)/1000)) + 'm',
             }
@@ -1285,43 +1293,43 @@ class MyStatsView(LoginRequiredMixin, TemplateView):
         stats = [
             {
                 'image': "svg/camera.svg",
-                'url': reverse('camera-list'),
+                'url': reverse('schema:camera-list'),
                 'item': "cameras in your collection right now",
                 'value': Camera.objects.filter(owner=self.request.user, own=True).count,
             },
             {
                 'image': "svg/camera.svg",
-                'url': reverse('camera-list'),
+                'url': reverse('schema:camera-list'),
                 'item': "cameras ever in your collection",
                 'value': Camera.objects.filter(owner=self.request.user).count,
             },
             {
                 'image': "svg/lens.svg",
-                'url': reverse('lens-list'),
+                'url': reverse('schema:lens-list'),
                 'item': "lenses in your collection right now",
                 'value': Lens.objects.filter(owner=self.request.user, own=True).count,
             },
             {
                 'image': "svg/lens.svg",
-                'url': reverse('lens-list'),
+                'url': reverse('schema:lens-list'),
                 'item': "lenses ever in your collection",
                 'value': Lens.objects.filter(owner=self.request.user).count,
             },
             {
                 'image': "svg/film.svg",
-                'url': reverse('film-list'),
+                'url': reverse('schema:film-list'),
                 'item': "films in your collection",
                 'value': Film.objects.filter(owner=self.request.user).count,
             },
             {
                 'image': "svg/negative.svg",
-                'url': reverse('negative-list'),
+                'url': reverse('schema:negative-list'),
                 'item': "negatives in your collection",
                 'value': Negative.objects.filter(owner=self.request.user).count,
             },
             {
                 'image': "svg/print.svg",
-                'url': reverse('print-list'),
+                'url': reverse('schema:print-list'),
                 'item': "prints in your collection",
                 'value': Print.objects.filter(owner=self.request.user).count,
             },
